#   Copyright [2011] [Tennessee Leeuwenburg <tleeuwenburg@gmail.com>]
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

'''
This module exists to provide integration between the benchmarker.py module
and the codespeed benchmarking visualisation server. Benchmarker.py will
work perfectly well without this module, as its job is simply data collection.

This module is loosely coupled, which is to say it is an integrated system
but does not depend on any benchmarker.py code. It works by assuming a particular
directory structure containing pstats files.

/top-level-directory
    project_information.txt: contains the codespeed metadata
    /YYYY
       /MM
           <revision_id>.pstats or <datetime.pstats>
           
If revision-id tagging was enabled, then this will integrate with codespeed
and set revision ids with each submission. If not, the date and time will
be used to track the changes instead. 
'''

from datetime import datetime
import urllib, urllib2

from configuration import CODESPEED_URL


sample_data = {
    'commitid': '2',
    'project': 'Manual Entry',
    'revision_date': '', # Optional. Default is taken
                         # either from VCS integration or from current date
    'executable': 'Tennessee',
    'benchmark': 'Large Frogs',
    'environment': "The Reformer",
    'result_value': 39,
    'result_date': datetime.today(), # Optional    
    'std_dev': 10., # Optional. Default is blank
    'max': 64., # Optional. Default is blank
    'min': 33., # Optional. Default is blank
}

def add(data):
    params = urllib.urlencode(sample_data)
    response = "None"
#    print "Executable %s, revision %s, benchmark %s" % (data['executable'], data['commitid'], data['benchmark'])
    url_part = CODESPEED_URL + 'result/add/'
    print url_part
    f = urllib2.urlopen(url_part, params)
    response = f.read()
    f.close()
    print "Server (%s) response: %s\n" % (CODESPEED_URL, response)

